<TS language="sr@latin" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Klikni desnim tasterom za uređivanje adrese ili oznake</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Kreiraj novu adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novi</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopiraj selektovanu adresu u sistemski klipbord</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiraj</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Briše trenutno izabranu adresu sa liste</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Unesite adresu ili oznaku za pretragu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvoz podataka iz trenutne kartice u datoteku</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvoz</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Izbrisati</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Izaberite adresu za slanje novčića</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Izaberite adresu za prijem novčića</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>I&amp;zaberi</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Adresa na koju se šalje</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Adresa na koju se prima</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Ovo su Vaše Bitcoin adrese na koju se vrše uplate. Uvek proverite iznos i prijemnu adresu pre slanja novčića.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopiraj Adresu</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopiranje &amp;Oznaka</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Izmena</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Izvezi Listu Adresa</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Zarezom odvojena datoteka (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Izvoz Neuspeo</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Desila se greška prilikom čuvanja liste adresa u %1. Molimo pokusajte ponovo.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez oznake)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialog pristupne fraze</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Unesi pristupnu frazu</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nova pristupna fraza</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ponovo unesite pristupnu frazu</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Prikaži lozinku</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Šifrujte novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Da biste otključali novčanik potrebno je da unesete svoju pristupnu frazu.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Otključajte novčanik</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Da biste dešifrovali novčanik, potrebno je da unesete svoju pristupnu frazu.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dešifrujte novčanik</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Promenite pristupnu frazu</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potvrdite šifrovanje novčanika</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Upozorenje: Ako šifrujete svoj novčanik, i potom izgubite svoju pristupnu frazu &lt;b&gt;IZGUBIĆETE SVE SVOJE BITKOINE&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Da li ste sigurni da želite da šifrujete svoj novčanik?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Novčanik je šifrovan</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Unesite lozinku u novčanik. &lt;br/&gt;Molimo, koristite lozinku koja ima &lt;b&gt; deset ili više nasumičnih znakova&lt;/b&gt;, ili &lt;b&gt;osam ili više reči&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Unesite u novčanik staru lozinku i novu lozinku.</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>Novčanik će vam biti šifriran.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>Vaš novčanik je sada šifrovan.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>VAŽNO: Ranije rezervne kopije wallet datoteke trebate zameniti sa novo-kreiranom, enkriptovanom wallet datotekom. Iz sigurnosnih razloga, ranije ne-enkriptovane wallet datoteke će postati neupotrebljive čim počnete koristiti novi, enkriptovani novčanik.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Enkripcija novčanika neuspešna</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Enkripcija novčanika nije uspela zbog greške u programu. Vaš novčanik nije enkriptovan.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Unete pristupne fraze nisu tačne.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Otključavanje novčanika neuspešno</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Pristupna fraza za dekriptovanje novčanika nije tačna.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Dekriptovanje novčanika neuspešno</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Pristupna fraza novčanika je uspešno promenjena.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Upozorenje: Caps Lock je uključen!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Banovani ste do</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Potpišite &amp;poruka...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Usklađivanje sa mrežom...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Pregled</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Prikaži opšti pregled novčanika</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakcije</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Pregled istorije transakcija</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>I&amp;zađi</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Isključi aplikaciju</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Otprilike %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Prikaži informacije za otprilike %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Prikaži informacije o Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opcije...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Izmeni podešavanja za %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Enkriptuj Novčanik...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Rezervna Kopija Novčanika...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Izmeni pristupnu frazu...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Otvori &amp;URI...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Novčanik:</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Odaberite za prekid aktivnosti na mreži.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Aktivnost na mreži je prekinuta.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Odaberite da ponovo dozvolite aktivnost na mreži.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Sinhronizujem Najnovije Blokove (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Ponovo obeležavam blokove na disku...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Pošalji novčiće na Bitcoin adresu</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Napravite rezervnu kopiju novčanika na drugom mestu</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Promenite pristupnu frazu za enkiptovanje novčanika</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Proveri poruku...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Pošalji</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Primi</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Prikazati / Sakriti</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Prikaži ili sakrij glavni prozor</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Enkriptuj privatne ključeve novčanika</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Potpišite poruke sa svojim Bitcoin adresama da biste dokazali njihovo vlasništvo</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Proverite poruke da biste utvrdili sa kojim Bitcoin adresama su potpisane</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fajl</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Podešavanja</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Alatke za tabove</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Zatražite plaćanje (generiše QR kodove i bitcoin: URI-e)</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>Otvori novčanik</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klijent</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datum: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Iznos: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tip: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Oznaka: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adresa: %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nakon Naknade:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kolicina</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez oznake)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation>Onemogućite privatne ključeve za ovaj novčanik. Novčanici sa isključenim privatnim ključevima neće imati privatne ključeve i ne mogu imati HD seme ili uvezene privatne ključeve. Ovo je idealno za novčanike samo za gledanje.</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Izmeni Adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Oznaka</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Kolicina</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nepoznato</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Novčanik:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Poruka</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez oznake)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Količina:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Iznos:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Naknada:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Nakon Naknade:</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Taksa transakcije</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez oznake)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/nepotvrdjeno</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 potvrdjeno/ih</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stanje/Status</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Izvor</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>Generisano</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Od</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nepoznato</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Kome</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>sopstvena adresa</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>samo za gledanje</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiketa</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Kredit</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>nije prihvaceno</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Zaduzenje</translation>
    </message>
    <message>
        <source>Total debit</source>
        <translation>Ukupno zaduzenje</translation>
    </message>
    <message>
        <source>Total credit</source>
        <translation>Totalni kredit</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Taksa transakcije</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Neto iznos</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Poruka</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentar</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>ID Transakcije</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation>Trgovac</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation>Informacije debugovanja</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transakcije</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation>Unosi</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kolicina</translation>
    </message>
    <message>
        <source>true</source>
        <translation>tacno</translation>
    </message>
    <message>
        <source>false</source>
        <translation>netacno</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Primljeno uz</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Primljeno od</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Poslat</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Placanje samom sebi</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Iskopano</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>samo za gledanje</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez oznake)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Received with</source>
        <translation>Primljeno uz</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Poslat</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Iskopano</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Zarezom odvojena datoteka (*.csv)</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tip</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Izvoz Neuspeo</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Izvoz</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvoz podataka iz trenutne kartice u datoteku</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Greska</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation>Nedovoljno sredstava</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Ucitavanje indeksa bloka...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ucitavanje novcanika...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ponovno skeniranje...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Zavrseno ucitavanje</translation>
    </message>
</context>
</TS>